@@ -10,12 +10,12 @@
 @Desc    :   用于快捷导入常用的包，注意这个文件不要格式化！
 """
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 
-###################################
-注意！！这个文件不要格式化！！！
-###################################
+# #######################################################
+# ### 注意！！这个文件不能格式化，否则下面的包顺序会乱掉！
+# #######################################################
 
 
 # ## 精简编程时的麻烦，常用的其他包的导入
